==> haskell-deriving-aeson-0.2.10-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-JBuvWn0Iy6oGudMNqO4rnk
key:                  deriving-aeson-0.2.10-JBuvWn0Iy6oGudMNqO4rnk
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  c2727a2637667fb8dd124d8c47699a40
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-JBuvWn0Iy6oGudMNqO4rnk
depends:              aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deriving-aeson-0.2.10-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-C5swYAcyyVV6TZ715iohp1
key:                  deriving-aeson-0.2.10-C5swYAcyyVV6TZ715iohp1
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  6ce486fb4285d91c3a7bf0c51a0346b1
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-C5swYAcyyVV6TZ715iohp1
depends:              aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
